@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -42,7 +42,7 @@ public:
     }
 
     void loadPlugin(MailTransportPluginInfo *item);
-    QVector<MailTransport::TransportAbstractPlugin *> pluginsList() const;
+    Q_REQUIRED_RESULT QVector<MailTransport::TransportAbstractPlugin *> pluginsList() const;
     QVector<MailTransportPluginInfo> mPluginList;
     void initializePlugins();
 
@@ -55,7 +55,7 @@ void TransportPluginManagerPrivate::initializePlugins()
     if (!mPluginList.isEmpty()) {
         return;
     }
-    const QVector<KPluginMetaData> plugins = KPluginMetaData::findPlugins(QStringLiteral("mailtransport"));
+    const QVector<KPluginMetaData> plugins = KPluginMetaData::findPlugins(QStringLiteral("kf" QT_STRINGIFY(QT_VERSION_MAJOR) "/mailtransport"));
 
     QVectorIterator<KPluginMetaData> i(plugins);
     i.toBack();
