@@ -16,7 +16,11 @@
 #include <KMessageBox>
 #include <KStringHandler>
 #include <KWallet>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <qt5keychain/keychain.h>
+#else
+#include <qt6keychain/keychain.h>
+#endif
 using namespace QKeychain;
 using namespace MailTransport;
 using namespace KWallet;
@@ -136,7 +140,7 @@ QString Transport::authenticationTypeString(int type)
         return QStringLiteral("XOAUTH2");
     }
     Q_ASSERT(false);
-    return QString();
+    return {};
 }
 
 void Transport::usrRead()
