@@ -9,8 +9,12 @@
 #include "kmailtransport_private_export.h"
 #include <QDialog>
 
+#include <memory>
+
 namespace MailTransport
 {
+class AddTransportDialogNGPrivate;
+
 /**
   @internal
 
@@ -42,8 +46,7 @@ public:
     void accept() override;
 
 private:
-    class Private;
-    Private *const d;
+    std::unique_ptr<AddTransportDialogNGPrivate> const d;
 };
 } // namespace MailTransport
 
